# pyraco

A python library for interacting with the retroarch network command interface.

* Free software: MIT license

## Installation

Use pip to install:

```
pip install pyraco
```

## Usage

The network command interface must be enabled (`network_cmd_enable = "true"` in retroarch.cfg).

A simple CLI is included, `pyraco`, which can test whether the connection is working.

**The current version is barely a proof of concept! Most commands are not supported.**
